==> open-xchange-documents-backend_7.10.4.orig.tar.bz2: open-xchange-documents-backend-7.10.4/com.openexchange.office.rest/src/com/openexchange/office/rest/operations/OperationsResult.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.rest.operations;

import org.apache.commons.lang3.Validate;
import org.json.JSONArray;
import org.json.JSONObject;

import com.openexchange.office.tools.common.error.ErrorCode;

public class OperationsResult implements OperationDataAccess {

    // ---------------------------------------------------------------
    private String htmlDoc;

    // ---------------------------------------------------------------
    private JSONObject previewData;

    // ---------------------------------------------------------------
    private JSONArray operations;

    // ---------------------------------------------------------------
    private ErrorCode errorCode;

    // ---------------------------------------------------------------
    private String hash;

    // ---------------------------------------------------------------
    public OperationsResult(final ErrorCode errorCode, final String htmlDoc, final JSONObject previewData, final JSONArray operations, final String hash) {
        this.errorCode = errorCode;
        this.htmlDoc = htmlDoc;
        this.operations = operations;
        this.previewData = previewData;
        this.hash = hash;
    }

    // ---------------------------------------------------------------
    public OperationsResult(final ErrorCode errorCode) {
        Validate.isTrue(errorCode.isError());

        this.errorCode = errorCode;
        this.htmlDoc = null;
        this.operations = null;
        this.previewData = null;
        this.hash = null;
    }

   // ---------------------------------------------------------------
    public ErrorCode getErrorCode() {
        return errorCode;
    }

    // ---------------------------------------------------------------
    @Override
    public String getHtmlDoc() {
        return htmlDoc;
    }

    // ---------------------------------------------------------------
    @Override
    public JSONObject getPreviewData() {
        return previewData;
    }

    // ---------------------------------------------------------------
    @Override
    public JSONArray getOperations() {
        return operations;
    }

    // ---------------------------------------------------------------
    @Override
    public String getHash() {
        return hash;
    }

}

==> open-xchange-documents-backend_7.10.5.orig.tar.bz2: open-xchange-documents-backend-7.10.5/com.openexchange.office.rest/src/com/openexchange/office/rest/operations/OperationsResult.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */



package com.openexchange.office.rest.operations;

import org.apache.commons.lang3.Validate;
import org.json.JSONArray;
import org.json.JSONObject;
import com.openexchange.office.datasource.access.MetaData;
import com.openexchange.office.tools.common.error.ErrorCode;

public class OperationsResult implements OperationDataAccess {

    // ---------------------------------------------------------------
    private String htmlDoc;

    // ---------------------------------------------------------------
    private JSONObject previewData;

    // ---------------------------------------------------------------
    private JSONArray operations;

    // ---------------------------------------------------------------
    private ErrorCode errorCode;

    // ---------------------------------------------------------------
    private MetaData metaData;

    // ---------------------------------------------------------------
    private String hash;

    // ---------------------------------------------------------------
    public OperationsResult(ErrorCode errorCode, MetaData metaData, String htmlDoc, JSONObject previewData, JSONArray operations, String hash) {
        this.errorCode = errorCode;
        this.metaData = metaData;
        this.htmlDoc = htmlDoc;
        this.operations = operations;
        this.previewData = previewData;
        this.hash = hash;
    }

    // ---------------------------------------------------------------
    public OperationsResult(final ErrorCode errorCode) {
        Validate.isTrue(errorCode.isError());

        this.errorCode = errorCode;
        this.htmlDoc = null;
        this.operations = null;
        this.previewData = null;
        this.hash = null;
    }

    // ---------------------------------------------------------------
    public MetaData getMetaData() {
        return metaData;
    }

   // ---------------------------------------------------------------
    public ErrorCode getErrorCode() {
        return errorCode;
    }

    // ---------------------------------------------------------------
    @Override
    public String getHtmlDoc() {
        return htmlDoc;
    }

    // ---------------------------------------------------------------
    @Override
    public JSONObject getPreviewData() {
        return previewData;
    }

    // ---------------------------------------------------------------
    @Override
    public JSONArray getOperations() {
        return operations;
    }

    // ---------------------------------------------------------------
    @Override
    public String getHash() {
        return hash;
    }

}
